@@ -16,9 +16,9 @@
 * limitations under the License.
 */
 #include "ByteArray.h"
-#include "ByteMatrix.h"
-#include "qrcode/QRCodecMode.h"
-#include "qrcode/QRVersion.h"
+#include "BitMatrix.h"
+#include "QRCodecMode.h"
+#include "QRVersion.h"
 
 namespace ZXing {
 namespace QRCode {
@@ -37,7 +37,7 @@ public:
 	CodecMode::Mode mode = CodecMode::TERMINATOR;
 	const Version* version = nullptr;
 	int maskPattern = -1;
-	ByteMatrix matrix;
+	BitMatrix matrix;
 };
 
 } // QRCode
